@@ -458,8 +458,21 @@ def abssymlink(symlink, target=None):
 
 _doebuild_manifest_exempt_depend = 0
 
-_testing_eapis = frozenset(["4-python", "4-slot-abi", "5-progress", "5-hdepend", "7_pre1", "7"])
-_deprecated_eapis = frozenset(["4_pre1", "3_pre2", "3_pre1", "5_pre1", "5_pre2", "6_pre1"])
+_testing_eapis = frozenset([
+	"4-python",
+	"5-progress",
+])
+_deprecated_eapis = frozenset([
+	"4_pre1",
+	"4-slot-abi",
+	"3_pre2",
+	"3_pre1",
+	"5_pre1",
+	"5_pre2",
+	"5-hdepend",
+	"6_pre1",
+	"7_pre1",
+])
 _supported_eapis = frozenset([str(x) for x in range(portage.const.EAPI + 1)] + list(_testing_eapis) + list(_deprecated_eapis))
 
 def _eapi_is_deprecated(eapi):
